@@ -155,7 +155,7 @@ def to_webp(src_path,**kwargs):
     '''
     delete_original_after = obj.get_kwarg(['delete after'], False, (bool), **kwargs)
     outputs = []
-    src_list = f._gen_path_list(src_path)    
+    src_list = f.gen_path_list(src_path)    
     
     for path in src_list:
         if f.exists(path) is False:
@@ -200,7 +200,7 @@ def to_jpg(src_path,**kwargs):
     '''
     delete_original_after = obj.get_kwarg(['delete after'], False, (bool), **kwargs)
     outputs = []
-    src_list = f._gen_path_list(src_path)    
+    src_list = f.gen_path_list(src_path)
     
     for path in src_list:
         if f.exists(path) is False:
